==> arduino-managed-2.10-sources.jar: li/rudin/arduino/managed/ManagedInterceptor.java <==
package li.rudin.arduino.managed;

import java.lang.reflect.Method;
import java.lang.reflect.Modifier;

import li.rudin.arduino.api.Arduino;
import li.rudin.arduino.api.ArduinoEthernet;
import li.rudin.arduino.managed.converter.TypeConverter;
import net.sf.cglib.proxy.MethodInterceptor;
import net.sf.cglib.proxy.MethodProxy;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ManagedInterceptor implements MethodInterceptor
{

	/**
	 * Local logger
	 */
	private static final Logger logger = LoggerFactory.getLogger(ManagedInterceptor.class);
	
	public ManagedInterceptor(Class<?> type, Arduino arduino)
	{
		this.arduino = arduino;
		this.type = type;
	}
	
	public final Arduino arduino;
	public final Class<?> type;
	

	@Override
	public Object intercept(Object obj, Method method, Object[] args, MethodProxy proxy) throws Throwable
	{		
		String methodName = method.getName();
		
		Class<?> methodOwner = method.getDeclaringClass();
		
		logger.trace("Intercepted method {}.{}", methodOwner.getSimpleName(), methodName);
		
		if (!Modifier.isAbstract(method.getModifiers()))
			return proxy.invokeSuper(obj, args);

		if (methodOwner == Arduino.class || methodOwner == ArduinoEthernet.class)
			//Delegate to device instance
			return proxy.invoke(arduino, args);
				
		if (methodName.startsWith("get"))
		{
			String key = methodName.substring(3, 4).toLowerCase() + methodName.substring(4);
			
			String str = arduino.get(key);
			
			if (str == null)
				throw new IllegalArgumentException("null-result from query: " + key);
			
			str = str.trim();
			Class<?> type = method.getReturnType();
			
			return TypeConverter.convertIncoming(str, type);
		}
		else if (methodName.startsWith("set"))
		{
			String key = methodName.substring(3, 4).toLowerCase() + methodName.substring(4);
			
			if (args.length == 1)
				arduino.send(key, TypeConverter.convertOutgoing(args[0]));
			
			else if (args.length == 0)
				arduino.send(key, "");
			
			return null;
		}
		else if (methodName.startsWith("do"))
		{
			String key = methodName.substring(2, 3).toLowerCase() + methodName.substring(3);

			if (args.length == 1)
				arduino.send(key, TypeConverter.convertOutgoing(args[0]));
			
			else if (args.length == 0)
				arduino.send(key, "");
			
		}
		
		return null;
	}


}

==> arduino-managed-2.12-sources.jar: li/rudin/arduino/managed/ManagedInterceptor.java <==
package li.rudin.arduino.managed;

import java.lang.reflect.Method;
import java.lang.reflect.Modifier;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import li.rudin.arduino.api.Arduino;
import li.rudin.arduino.api.ArduinoEthernet;
import li.rudin.arduino.api.cdi.Attributes;
import li.rudin.arduino.api.enums.Attribute;
import li.rudin.arduino.managed.converter.TypeConverter;
import net.sf.cglib.proxy.MethodInterceptor;
import net.sf.cglib.proxy.MethodProxy;

public class ManagedInterceptor implements MethodInterceptor
{

	/**
	 * Local logger
	 */
	private static final Logger logger = LoggerFactory.getLogger(ManagedInterceptor.class);
	
	public ManagedInterceptor(Class<?> type, Arduino arduino)
	{
		this.arduino = arduino;
		this.type = type;
	}
	
	public final Arduino arduino;
	public final Class<?> type;
	

	@Override
	public Object intercept(Object obj, Method method, Object[] args, MethodProxy proxy) throws Throwable
	{		
		String methodName = method.getName();
		Attributes attributeAnnotation = method.getAnnotation(Attributes.class);
		
		Attribute[] attributes = attributeAnnotation == null ? new Attribute[]{} : attributeAnnotation.value();
		
		Class<?> methodOwner = method.getDeclaringClass();
		
		logger.trace("Intercepted method {}.{}", methodOwner.getSimpleName(), methodName);
		
		if (!Modifier.isAbstract(method.getModifiers()))
			return proxy.invokeSuper(obj, args);

		if (methodOwner == Arduino.class || methodOwner == ArduinoEthernet.class)
			//Delegate to device instance
			return proxy.invoke(arduino, args);
				
		if (methodName.startsWith("get"))
		{
			String key = methodName.substring(3, 4).toLowerCase() + methodName.substring(4);
			
			String str = arduino.get(key, attributes);
			
			if (str == null)
				throw new IllegalArgumentException("null-result from query: " + key);
			
			str = str.trim();
			Class<?> type = method.getReturnType();
			
			return TypeConverter.convertIncoming(str, type);
		}
		else if (methodName.startsWith("set"))
		{
			String key = methodName.substring(3, 4).toLowerCase() + methodName.substring(4);
			
			if (args.length == 1)
				arduino.send(key, TypeConverter.convertOutgoing(args[0]));
			
			else if (args.length == 0)
				arduino.send(key, "");
			
			return null;
		}
		else if (methodName.startsWith("do"))
		{
			String key = methodName.substring(2, 3).toLowerCase() + methodName.substring(3);

			if (args.length == 1)
				arduino.send(key, TypeConverter.convertOutgoing(args[0]));
			
			else if (args.length == 0)
				arduino.send(key, "");
			
		}
		
		return null;
	}


}
